@@ -1,6 +1,47 @@
-#Topic Labeling according to a series of metrics.
-
+#' Label topics
+#' 
+#' Generate a set of words describing each topic from a fitted STM object.
+#' Uses a variety of labeling algorithms (see details).
+#' 
+#' Four different types of word weightings are printed with label topics.
+#' 
+#' Highest Prob: are the words within each topic with the highest probability
+#' (inferred directly from topic-word distribution parameter \eqn{\beta}).
+#' 
+#' FREX: are the words that are both frequent and exclusive, identifying words
+#' that distinguish topics.  This is calculated by taking the harmonic mean of
+#' rank by probability within the topic (frequency) and rank by distribution of
+#' topic given word \eqn{p(z|w=v)} (exclusivity).  In estimating exclusivity we
+#' use a James-Stein type shrinkage estimator of the distribution
+#' \eqn{p(z|w=v)}.  More information can be found in the documentation for the
+#' internal function \code{\link{calcfrex}} and \code{\link{js.estimate}}.
+#' 
+#' Score and Lift are measures provided in two other popular text mining
+#' packages. For more information on type Score, see the R package
+#' \code{\link{lda}} or the internal function \code{\link{calcscore}}.  
+#' For more information on type Lift, see the R package \code{maptpx}
+#' or or the internal function \code{\link{calclift}}.
+#' 
+#' @aliases labelTopics print.labelTopics
+#' @param model An \code{STM} model object.
+#' @param topics A vector of numbers indicating the topics to include.  Default
+#' is all topics.
+#' @param n The desired number of words (per type) used to label each topic.
+#' Must be 1 or greater.
+#' @param frexweight A weight used in our approximate FREX scoring algorithm
+#' (see details).
+#' @return A labelTopics object (list) \item{prob }{matrix of highest
+#' probability words} \item{frex }{matrix of highest ranking frex words}
+#' \item{lift }{matrix of highest scoring words by lift} \item{score }{matrix
+#' of best words by score} \item{topicnums }{a vector of topic numbers which
+#' correspond to the rows}
+#' @seealso \code{\link{stm}} \code{\link{plot.STM}} 
+#' \code{\link{calcfrex}} \code{\link{js.estimate}} \code{\link{calcscore}} \code{\link{calclift}}
+#' @examples
+#' labelTopics(gadarianFit)
+#' @export
 labelTopics <- function (model, topics=NULL, n = 7, frexweight=.5) {
+  if(n<1) stop("n must be 1 or greater")
   logbeta <- model$beta$logbeta
   K <- model$settings$dim$K
   vocab <- model$vocab
@@ -9,7 +50,11 @@ labelTopics <- function (model, topics=NULL, n = 7, frexweight=.5) {
   aspect <- length(logbeta)>1
 
   out <- list()
-  if(!aspect) {    
+  if(!aspect) {
+    out$prob <- list()
+    out$frex <- list()
+    out$lift <- list()
+    out$score <- list()
     logbeta <- logbeta[[1]]
     wordcounts <- model$settings$dim$wcounts$x
     #Calculate FREX Score
@@ -69,6 +114,8 @@ labelTopics <- function (model, topics=NULL, n = 7, frexweight=.5) {
   return(out)
 }
 
+#' @method print labelTopics
+#' @export
 print.labelTopics <- function(x,...) {  
   #test of its an aspect model or not
   if(names(x)[1]!="topics") {
@@ -105,6 +152,4 @@ print.labelTopics <- function(x,...) {
     }
     cat(labels)
   }
-}
-  
-  
+}
\ No newline at end of file
