@@ -25,3 +25,14 @@ test_that("Test that Content works", {
   expect_identical(class(test), "STM")
 })
 
+test_that("Test that ngroups works", {
+  test <- stm(poliblog5k.docs, poliblog5k.voc, K=3, init.type="Random",
+              ngroups=2, max.em.its=2)
+  expect_identical(class(test), "STM")
+})
+
+#test_that("Test that multi-core searchK works", {
+#  test <- searchK(poliblog5k.docs, poliblog5k.voc, K=c(3,4), 
+#                     init.type="Random", max.em.its=1, cores = 2)
+#  expect_identical(class(test), "searchK")
+#})
